# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .search_concept import SearchConcept


class CohortResponse(UniversalBaseModel):
    success: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the cohort analysis was successful
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Human-readable message about the analysis result
    """

    queries: typing.Optional[typing.List[SearchConcept]] = pydantic.Field(default=None)
    """
    Array of search concepts converted to FHIR search queries
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
